Method: Paperclip::Attachment#path

Defined in:
lib/paperclip/attachment.rb

#path(style_name = default_style) ⇒ Object

Returns the path of the attachment as defined by the :path option. If the file is stored in the filesystem the path refers to the path of the file on disk. If the file is stored in S3, the path is the “key” part of the URL, and the :bucket option refers to the S3 bucket.



169
170
171
172
# File 'lib/paperclip/attachment.rb', line 169

def path(style_name = default_style)
  path = original_filename.nil? ? nil : interpolate(path_option, style_name)
  path.respond_to?(:unescape) ? path.unescape : path
end